pub struct CountingSink {
pub blocks: u64,
pub frames: u64,
pub bytes: u64,
pub last_end: Micros,
pub rejected: u64,
/* private fields */
}Expand description
Counts what it is given and remembers where the stream has got to.
Fields
blocks: u64Blocks accepted.
frames: u64Sample frames accepted.
bytes: u64Bytes accepted.
last_end: MicrosEnd timestamp of the last block.
rejected: u64Blocks refused because their format did not match the first one.
Implementations
Sourceimpl CountingSink
impl CountingSink